# PygameUI

This code was extracted and simplified from [TowerDefenseV2](https://github.com/ArthurLeFloch/TowerDefenseV2).

# Presentation
This code allows to create these UI elements :
- Button
- ImageButton
- Slider
- CheckBox
- Text

# Callbacks
These elements come with callbacks :
- Button : `on_click`
- ImageButton : `on_click`
- Slider : `on_value_changed` (takes value as argument)
- CheckBox : `on_check`, `on_uncheck`, `on_action` (check or uncheck)
- Text : nothing
